@@ -84,7 +84,7 @@ class Cargo(models.Model):
     service_provider = models.ForeignKey(ServiceProvider, verbose_name="服务企业", on_delete=models.CASCADE)
 
     class Meta:
-        unique_together = ['code', 'hs_code', 'name', 'service_provider']
+        # unique_together = ['code', 'hs_code', 'name', 'service_provider']
         verbose_name = "货物"
         verbose_name_plural = verbose_name
         db_table = "p_cargo"
@@ -158,12 +158,13 @@ class WorkRoute(models.Model):
     """
     作业路线(tlms)
     """
+    code = models.CharField(max_length=20, verbose_name="作业路线编码", help_text="作业路线编码")
     name = models.CharField(max_length=20, verbose_name="作业路线名称", help_text="作业路线名称")
     if_deleted = models.BooleanField(default=False, verbose_name="是否删除")
     service_provider = models.ForeignKey(ServiceProvider, verbose_name="服务企业", on_delete=models.CASCADE)
 
     class Meta:
-        unique_together = ['name', 'service_provider']
+        unique_together = ['code', 'service_provider']
         verbose_name = "作业路线"
         verbose_name_plural = verbose_name
         db_table = "p_work_route"
